@@ -2,7 +2,7 @@
 This module provides a class to represent circuits as graphs.
 This is primarily for loop analysis but is also used for nodal analysis.
 
-Copyright 2019--2020 Michael Hayes, UCECE
+Copyright 2019--2021 Michael Hayes, UCECE
 
 """
 
@@ -18,17 +18,24 @@ import networkx as nx
 # W 2 6; up
 # C1 5 6; right=2
 
-class CircuitGraph(nx.Graph):
+class CircuitGraph(object):
 
-    def __init__(self, cct):
+    def __init__(self, cct, G=None):
 
-        super(CircuitGraph, self).__init__()
         self.cct = cct
-        self.dummy = 0
-        # Dummy nodes are used to avoid parallel edges.
-        self.dummy_nodes = {}
+        self.node_map = cct.node_map
 
-        self.add_nodes_from(cct.node_list)
+        if G is not None:
+            self.G = G
+            return
+        
+        self.G = nx.Graph()
+        
+        dummy = 0
+        # Dummy nodes are used to avoid parallel edges.
+        dummy_nodes = {}
+
+        self.G.add_nodes_from(cct.node_list)
 
         node_map = cct.node_map
 
@@ -40,18 +47,17 @@ class CircuitGraph(nx.Graph):
             nodename1 = node_map[elt.nodenames[0]]
             nodename2 = node_map[elt.nodenames[1]]
             
-            if self.has_edge(nodename1, nodename2):
+            if self.G.has_edge(nodename1, nodename2):
                 # Add dummy node in graph to avoid parallel edges.
-                dummynode = '*%d' % self.dummy
-                dummycpt = 'W%d' % self.dummy                
-                self.add_edge(nodename1, dummynode, name=name)
-                self.add_edge(dummynode, nodename2, name=dummycpt)
-                self.dummy_nodes[dummynode] = nodename2
-                self.dummy += 1
+                dummynode = '*%d' % dummy
+                dummycpt = 'W%d' % dummy                
+                self.G.add_edge(nodename1, dummynode, name=name)
+                self.G.add_edge(dummynode, nodename2, name=dummycpt)
+                dummy_nodes[dummynode] = nodename2
+                dummy += 1
             else:
-                self.add_edge(nodename1, nodename2, name=name)
+                self.G.add_edge(nodename1, nodename2, name=name)
 
-        self.node_map = node_map
 
     def connected_cpts(self, node):
         """Components connected to specified node."""
@@ -75,7 +81,7 @@ class CircuitGraph(nx.Graph):
     def all_loops(self):
 
         # This adds forward and backward edges.
-        DG = nx.DiGraph(self)
+        DG = nx.DiGraph(self.G)
         cycles = list(nx.simple_cycles(DG))
 
         loops = []
@@ -92,7 +98,7 @@ class CircuitGraph(nx.Graph):
         loops = self.all_loops()
         sets = [set(loop) for loop in loops]
 
-        DG = nx.DiGraph(self)
+        DG = nx.DiGraph(self.G)
         
         rejects = []
         for i in range(len(sets)):
@@ -115,7 +121,34 @@ class CircuitGraph(nx.Graph):
 
         return cloops
 
+    def cut_sets(self):
+        """Return list of cut sets.  Each cut set is a set of nodes describing
+        a sub-graph G'.  Removing all the edges of G' from the graph
+        disconnects it.  This will fail if there are unconnected
+        components."""
+
+        # It may be better to return a list of sets of edges.
+        
+        if hasattr(self, '_cutsets'):
+            return self._cutsets
+        self._cutsets = list(nx.all_node_cuts(self.G))
+        return self._cutsets
+
+    def cut_vertices(self):
+        """Return list of cut vertices.  Each cut vertex is a node
+        that if removed, with its edges, disconnects the graph."""
+
+        return list(nx.articulation_points(self.G))
+
+    def cut_edges(self):
+        """Return list of cut edges.  Each cut edge is an edge that 
+        disconnects the graph if removed."""
+
+        return list(nx.minimum_edge_cut(self.G))    
+
     def loops(self):
+        """Return list of loops:  Each loop is a list of nodes."""
+        
         if hasattr(self, '_loops'):
             return self._loops
         self._loops = self.chordless_loops()
@@ -142,7 +175,7 @@ class CircuitGraph(nx.Graph):
 
         fig, ax = subplots(1)
 
-        G = self
+        G = self.G
         pos = nx.spring_layout(G)
         
         labels = dict(zip(G.nodes(), G.nodes()))
@@ -159,15 +192,23 @@ class CircuitGraph(nx.Graph):
     def is_planar(self):
         """Return True for a planar network."""
         
-        return nx.check_planarity(self)[0]
+        return nx.check_planarity(self.G)[0]
 
+    @property    
+    def nodes(self):
+        """Return nodes comprising network."""
+        
+        return self.G.nodes()
+    
     def node_edges(self, node):
+        """Return edges connected to specified node."""        
 
-        return self[node]
+        return self.G[node]
 
     def component(self, node1, node2):
+        """Return component connected between specified nodes."""                
 
-        name = self.get_edge_data(node1, node2)['name']
+        name = self.G.get_edge_data(node1, node2)['name']
         if name.startswith('W'):
             return None
         return self.cct.elements[name]
@@ -208,10 +249,10 @@ class CircuitGraph(nx.Graph):
     def components(self):
         """Return list of component names."""
 
-        return [d['name'] for n1, n2, d in self.edges(data=True)]
+        return [d['name'] for n1, n2, d in self.G.edges(data=True)]
 
     def in_series(self, cpt_name):
-        """Return set of component names in series with cpt including itself."""        
+        """Return set of component names in series with cpt including itself."""
 
         cct = self.cct
         elt = cct.elements[cpt_name]
@@ -221,7 +262,7 @@ class CircuitGraph(nx.Graph):
         series.append(cpt_name)        
 
         def follow(node):
-            neighbours = self[node]
+            neighbours = self.G[node]
             if len(neighbours) > 2:
                 return
             for n, e in neighbours.items():
@@ -257,12 +298,12 @@ class CircuitGraph(nx.Graph):
 
         parallel = [cpt_name]
 
-        neighbours1 = self[n1]
-        neighbours2 = self[n2]
+        neighbours1 = self.G[n1]
+        neighbours2 = self.G[n2]
 
         # The first created parallel component has no dummy nodes.
         try:
-            name = self.get_edge_data(n1, n2)['name']
+            name = self.G.get_edge_data(n1, n2)['name']
             parallel.append(name)
         except:
             pass
@@ -271,23 +312,76 @@ class CircuitGraph(nx.Graph):
         
         for n, e in neighbours1.items():
             if n.startswith('*'):
-                for n3, e3 in self[n].items():
+                for n3, e3 in self.G[n].items():
                     if n3 == n2 and not e['name'].startswith('W'):
                         parallel.append(e['name'])
         for n, e in neighbours2.items():
             if n.startswith('*'):
-                for n3, e3 in self[n].items():
+                for n3, e3 in self.G[n].items():
                     if n3 == n1 and not e['name'].startswith('W'):
                         parallel.append(e['name'])
 
         if n1.startswith('*'):
-            for n3, e3 in self[n1].items():
+            for n3, e3 in self.G[n1].items():
                 if n3 == n2 and not e['name'].startswith('W'):
                     parallel.append(e['name'])
         if n2.startswith('*'):
-            for n3, e3 in self[n2].items():
+            for n3, e3 in self.G[n2].items():
                 if n3 == n1 and not e['name'].startswith('W'):
                     parallel.append(e['name'])                                            
         
         return set(parallel)
 
+    @property    
+    def node_connectivity(self):
+        """Return node connectivity for graph.  If the connectivity is 0,
+        then there are disconnected components.  If there is a component
+        with a single connected node, the connectivity is 1."""
+
+        return nx.node_connectivity(self.G)
+
+    @property
+    def is_connected(self):
+        """Return True if all components are connected."""
+
+        return self.node_connectivity != 0
+
+    def tree(self):
+        """Return minimum spanning tree.  A tree has no loops so no current flows."""
+
+        # The removed edges from the graph are called links.
+
+        T = nx.minimum_spanning_tree(self.G)
+        return CircuitGraph(self.cct, T)
+
+    @property
+    def num_parts(self):
+
+        if self.is_connected:
+            return 1
+        raise ValueError('TODO, calculate number of separate graphs')
+
+    @property
+    def num_nodes(self):
+        """The number of nodes in the graph."""        
+
+        return len(self.G.nodes)
+
+    @property
+    def num_branches(self):
+        """The number of branches (edges) in the graph."""
+
+        return len(self.G.edges)    
+
+    @property
+    def rank(self):
+        """The required number of node voltages for nodal analysis."""
+
+        return self.num_nodes - self.num_parts
+
+    @property
+    def nullity(self):
+        """For a planar circuit, this is equal to the number of meshes in the graph."""
+
+        return self.num_branches - self.num_nodes + self.num_parts    
+    
