@@ -1,9 +1,9 @@
-"""This module provides functions.
+"""This module wraps SymPy functions and provides a few others.
 
-Copyright 2014--2020 Michael Hayes, UCECE
+Copyright 2014--2021 Michael Hayes, UCECE
 """
 
-
+from .units import u as uu
 import sympy as sym
 
 class Function(object):
@@ -13,8 +13,6 @@ class Function(object):
     
     def __call__(self, *args):
 
-        cls = args[0].__class__
-
         # Unwrap expressions
         tweak_args = list(args)
         for m, arg in enumerate(args):
@@ -25,18 +23,25 @@ class Function(object):
 
         if isinstance(args[0], Expr):
 
-            result = cls(result)
+            cls = args[0].__class__
+            result = cls(result)        
+            
             if args[0].is_phase and self.expr in (sym.sin, sym.cos, sym.tan, sym.exp,
                                                   sym.sinh, sym.cosh, sym.tanh):
                 result.part = ''
+            elif self.expr in (sym.atan, sym.atan2):
+                result.units = uu.rad
+            elif self.expr == sym.diff and isinstance(args[1], Expr):
+                result.units = args[0].units / args[1].units
+            elif self.expr == sym.integrate:
+                if isinstance(args[1], Expr):
+                    result.units = args[0].units * args[1].units
+                elif isinstance(args[1], tuple) and isinstance(args[1][0], Expr):
+                    result.units = args[0].units * args[1][0].units
+            elif self.expr is sym.DiracDelta and isinstance(args[0], Expr):
+                result.units = 1 / args[0].units                
 
-        if False:
-            for m, arg in enumerate(args[1:]):
-                if isinstance(arg, (Expr, Function)):
-                    # Need to avoid substituting constants
-                    result = result.subs(tweak_args[m], arg)
-
-        return expr(result)
+        return result
 
     def pdb(self):
         import pdb; pdb.set_trace()
@@ -97,6 +102,10 @@ gcd = Function(sym.gcd)
 
 sign = Function(sym.sign)
 
+diff = Function(sym.diff)
+
+integrate = Function(sym.integrate)
+
 u = H = heaviside = Heaviside = Function(sym.Heaviside)
 
 delta = DiracDelta = Function(sym.DiracDelta)
