@@ -9,10 +9,11 @@ from __future__ import division
 from .domains import TimeDomain
 from .expr import Expr
 from .functions import exp
-from .sym import fsym, ssym, tsym, j, oo, tausym
+from .sym import fsym, ssym, tsym, j, oo
 from .laplace import laplace_transform
 from .fourier import fourier_transform
-from sympy import Heaviside, limit, Integral, Expr as symExpr
+from .units import u as uu
+from sympy import Heaviside, Integral, limit, Expr as symExpr
 
 
 __all__ = ('texpr', )
@@ -50,6 +51,12 @@ class TimeDomainExpression(TimeDomain, Expr):
         
         return x.is_constant_domain
 
+    @property
+    def abs(self):
+        """Return absolute value."""
+
+        return self.__class__(abs(self.expr), **self.assumptions)
+        
     def as_expr(self):
         return TimeDomainExpression(self)
 
@@ -69,7 +76,7 @@ class TimeDomainExpression(TimeDomain, Expr):
 
         assumptions = self.assumptions.merge_and_infer(self, **assumptions)
         result = laplace_transform(self.expr, self.var, ssym, evaluate=evaluate)
-        return self.change(result, domain='laplace', **assumptions)
+        return self.change(result, domain='laplace', units_scale=uu.s, **assumptions)
 
     def phasor(self, **assumptions):
         """Convert to phasor domain."""
@@ -90,7 +97,7 @@ class TimeDomainExpression(TimeDomain, Expr):
 
         assumptions = self.assumptions.merge_and_infer(self, **assumptions)
         result = fourier_transform(self.expr, self.var, fsym, evaluate=evaluate)
-        return self.change(result, domain='fourier', **assumptions)
+        return self.change(result, domain='fourier', units_scale=uu.s, **assumptions)
 
     def angular_fourier(self, evaluate=True, **assumptions):
         """Attempt angular Fourier transform."""
@@ -100,7 +107,7 @@ class TimeDomainExpression(TimeDomain, Expr):
         assumptions = self.assumptions.merge_and_infer(self, **assumptions)
         result = self.fourier(evaluate, **assumptions).subs(f, omega / (2 * pi))
         # Could optimise...
-        return self.change(result, domain='angular fourier', **assumptions)
+        return self.change(result, domain='angular fourier', units_scale=uu.s, **assumptions)
 
     def time(self, **assumptions):
         return self
@@ -177,21 +184,6 @@ class TimeDomainExpression(TimeDomain, Expr):
         expr = expr * Heaviside(t)
         return self.__class__(expr)        
 
-    def convolve(self, impulseresponse, commutate=False, **assumptions):
-        """Convolve self with impulse response."""
-
-        if not isinstance(impulseresponse, TimeDomainExpression):
-            raise ValueError('Expecting TimeDomainExpression for impulse response')
-
-        f1 = self.expr
-        f2 = impulseresponse.expr
-        if commutate:
-            f1, f2 = f2, f1
-        result = Integral(f1.subs(self.var, self.var - tausym) *
-                          f2.subs(self.var, tausym),
-                          (tausym, -oo, oo))
-        return self.__class__(result, **assumptions)
-
     
 class TimeDomainImpulseResponse(TimeDomainExpression):
     """Time-domain impulse response."""
@@ -199,7 +191,7 @@ class TimeDomainImpulseResponse(TimeDomainExpression):
     # TODO, check attributes.
     quantity = 'transfer'
     quantity_label = 'Impulse response'
-    units = '1/s'
+    domain_units = uu.Hz
     is_transfer = True
 
 
@@ -218,3 +210,4 @@ TimeDomainVoltage = classes['voltage']
 TimeDomainCurrent = classes['current']
 
 t = TimeDomainExpression('t')
+t.units = uu.s
