@@ -4,7 +4,7 @@ class VoltageSquaredMixin(Quantity):
 
     quantity = 'voltagesquared'
     quantity_label = 'Voltage^2'
-    units = 'V^2'
+    quantity_units = 'V^2'
     is_voltagesquared = True
 
 
